@@ -1,6 +1,6 @@
-/* -*- C -*- 
+/*
   mboxgrep - scan mailbox for messages matching a regular expression
-  Copyright (C) 2000, 2001, 2002, 2003  Daniel Spiljar
+  Copyright (C) 2000 - 2003, 2023  Daniel Spiljar
 
   Mboxgrep is free software; you can redistribute it and/or modify it 
   under the terms of the GNU General Public License as published by
@@ -15,13 +15,12 @@
   You should have received a copy of the GNU General Public License
   along with mboxgrep; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-  $Id: info.h,v 1.5 2003/04/13 19:15:58 dspiljar Exp $ */
+*/
 
 #ifndef INFO_H
-#define INFO_H
+#  define INFO_H
 
-void print_wrap (char *str, int len, int *n);
+void print_wrap (char *str);
 void version (void);
 void help (void);
 void usage (void);
