@@ -1,6 +1,6 @@
-/* -*- C -*- 
+/*
    mboxgrep - scan mailbox for messages matching a regular expression
-   Copyright (C) 2000, 2001, 2002, 2003  Daniel Spiljar
+   Copyright (C) 2000 - 2004, 2023 - 2024 Daniel Spiljar
    
    Mboxgrep is free software; you can redistribute it and/or modify it 
    under the terms of the GNU General Public License as published by
@@ -15,15 +15,12 @@
    You should have received a copy of the GNU General Public License
    along with mboxgrep; if not, write to the Free Software Foundation, 
    Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-   
-   $Id: mbox.h,v 1.9 2003/08/24 19:23:50 dspiljar Exp $ */
+*/
 
 #ifndef MBOX_H
-#define MBOX_H 1
-
-#include <config.h>
-
-#include "mboxgrep.h"           /* for message_t structure */
+#  define MBOX_H 1
+#  include <config.h>
+#  include "message.h"
 
 typedef struct
 {
@@ -32,10 +29,23 @@ typedef struct
   char *postmark_cache;
 } mbox_t;
 
+typedef enum
+{
+  r,
+  w,
+} mbox_mode_t;
 
-mbox_t *mbox_open (const char *path, const char *mode);
-void *tmpfile_open (const char *path);
+
+mbox_t *mbox_open (const char *path, const mbox_mode_t mbox_mode);
+void tmpmbox_create (const char *path);
+void tmpfile_name (const char *path);
+void tmpfile_mod_own (const int fd, const char *path);
+int tmpfile_create (void);
 void mbox_close (mbox_t * mbp);
-message_t *mbox_read_message (mbox_t * mbp);
+message_t *mbox_read_message (mbox_t * mp);
+void mbox_write_message (message_t * m, mbox_t * mbox);
+void mbox_lock (int fd, const char *path, const mbox_mode_t mbox_mode);
+void *mbox_fdopen (int fd, const char *path, const mbox_mode_t mbox_mode);
+char *mbox_check_postmark(mbox_t *mp, const char *path);
 
 #endif /* MBOX_H */
