@@ -1,6 +1,6 @@
-/* -*- C -*- 
+/*
   mboxgrep - scan mailbox for messages matching a regular expression
-  Copyright (C) 2000, 2001, 2002, 2003  Daniel Spiljar
+  Copyright (C) 2000 - 2003, 2006, 2023  Daniel Spiljar
 
   Mboxgrep is free software; you can redistribute it and/or modify it 
   under the terms of the GNU General Public License as published by
@@ -15,18 +15,27 @@
   You should have received a copy of the GNU General Public License
   along with mboxgrep; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-  $Id: misc.h,v 1.5 2003/03/30 23:07:10 dspiljar Exp $ */
+*/
 
 #ifndef MISC_H
-#define MISC_H 1
+#  define MISC_H 1
 
-#include "mboxgrep.h"
-#include <time.h>
+#  include "mboxgrep.h"
+#  include "getopt.h"
+#  include "message.h"
+/* #include <time.h> */
 
-format_t folder_format (const char *name);
-lockmethod_t lock_method (const char *name);
-time_t parse_date(char *datestr);
-char * parse_return_path(char *rpath);
+void set_folder_format (const char *name);
+void set_lock_method (const char *name);
+/* time_t parse_date(char *datestr); */
+char *parse_return_path (char *rpath);
+void *allocate_message (void);
+void postmark_print (message_t * msg);
+void init_options (void);
+void get_options (int *argc, char **argv,
+                          struct option *long_options);
+void check_options (void);
+void set_option_action (action_t action, char *path);
+void set_option_regextype (regextype_t regextype);
 
 #endif /* MISC_H */
